# -*- coding: utf-8 -*-
"""
Views for newsletter subscription
"""
from django.core.urlresolvers import reverse
from django.views.generic.edit import FormView
from django.views.generic.base import TemplateView

from newsletter_subscriptions.forms import SubscriptionForm
from newsletter_subscriptions.helpers import helper_finder, SubscriptionFormHelper


class SubscribeFormView(FormView):
    template_name = 'newsletter_subscriptions/form.html'
    success_urlname = 'newsletter-subscribe-sent'
    form_class = SubscriptionForm
    form_helper_class = SubscriptionFormHelper

    def get_form_helper_class(self):
        return helper_finder(self.form_helper_class)

    def get_form_helper(self):
        helper_class = self.get_form_helper_class()
        kwargs = self.get_form_helper_kwargs()
        return helper_class(**kwargs)

    def get_form_helper_kwargs(self):
        return {}

    def get_success_url(self):
        return reverse(self.success_urlname)

    def get_context_data(self, **kw):
        context = super(SubscribeFormView, self).get_context_data(**kw)
        context.update({
            'form_helper': self.get_form_helper(),
        })
        return context

    def form_valid(self, form):
        form.save()
        return super(SubscribeFormView, self).form_valid(form)


class SubscribeConfirmView(TemplateView):
    template_name = 'newsletter_subscriptions/form_sent.html'
